Class: Google::Apis::AnalyticshubV1::AnalyticsHubService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::AnalyticshubV1::AnalyticsHubService
- Defined in:
- lib/google/apis/analyticshub_v1/service.rb
Overview
Analytics Hub API
Exchange data and analytics assets securely and efficiently.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://analyticshub.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#approve_query_template(name, approve_query_template_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AnalyticshubV1::QueryTemplate
Approves a query template.
-
#create_project_location_data_exchange(parent, data_exchange_object = nil, data_exchange_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AnalyticshubV1::DataExchange
Creates a new data exchange.
-
#create_project_location_data_exchange_listing(parent, listing_object = nil, listing_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AnalyticshubV1::Listing
Creates a new listing.
-
#create_project_location_data_exchange_query_template(parent, query_template_object = nil, query_template_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AnalyticshubV1::QueryTemplate
Creates a new QueryTemplate.
-
#delete_project_location_data_exchange(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AnalyticshubV1::Empty
Deletes an existing data exchange.
-
#delete_project_location_data_exchange_listing(name, delete_commercial: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AnalyticshubV1::Empty
Deletes a listing.
-
#delete_project_location_data_exchange_query_template(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AnalyticshubV1::Empty
Deletes a query template.
-
#delete_project_location_subscription(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AnalyticshubV1::Operation
Deletes a subscription.
-
#get_data_exchange_iam_policy(resource, get_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AnalyticshubV1::Policy
Gets the IAM policy.
-
#get_listing_iam_policy(resource, get_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AnalyticshubV1::Policy
Gets the IAM policy.
-
#get_project_location_data_exchange(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AnalyticshubV1::DataExchange
Gets the details of a data exchange.
-
#get_project_location_data_exchange_listing(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AnalyticshubV1::Listing
Gets the details of a listing.
-
#get_project_location_data_exchange_query_template(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AnalyticshubV1::QueryTemplate
Gets a QueryTemplate.
-
#get_project_location_subscription(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AnalyticshubV1::Subscription
Gets the details of a Subscription.
-
#get_subscription_iam_policy(resource, get_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AnalyticshubV1::Policy
Gets the IAM policy.
-
#initialize ⇒ AnalyticsHubService
constructor
A new instance of AnalyticsHubService.
-
#list_organization_location_data_exchanges(organization, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AnalyticshubV1::ListOrgDataExchangesResponse
Lists all data exchanges from projects in a given organization and location.
-
#list_project_location_data_exchange_listing_subscriptions(resource, include_deleted_subscriptions: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AnalyticshubV1::ListSharedResourceSubscriptionsResponse
Lists all subscriptions on a given Data Exchange or Listing.
-
#list_project_location_data_exchange_listings(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AnalyticshubV1::ListListingsResponse
Lists all listings in a given project and location.
-
#list_project_location_data_exchange_query_templates(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AnalyticshubV1::ListQueryTemplatesResponse
Lists all QueryTemplates in a given project and location.
-
#list_project_location_data_exchange_subscriptions(resource, include_deleted_subscriptions: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AnalyticshubV1::ListSharedResourceSubscriptionsResponse
Lists all subscriptions on a given Data Exchange or Listing.
-
#list_project_location_data_exchanges(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AnalyticshubV1::ListDataExchangesResponse
Lists all data exchanges in a given project and location.
-
#list_project_location_subscriptions(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AnalyticshubV1::ListSubscriptionsResponse
Lists all subscriptions in a given project and location.
-
#patch_project_location_data_exchange(name, data_exchange_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AnalyticshubV1::DataExchange
Updates an existing data exchange.
-
#patch_project_location_data_exchange_listing(name, listing_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AnalyticshubV1::Listing
Updates an existing listing.
-
#patch_project_location_data_exchange_query_template(name, query_template_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AnalyticshubV1::QueryTemplate
Updates an existing QueryTemplate.
-
#refresh_subscription(name, refresh_subscription_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AnalyticshubV1::Operation
Refreshes a Subscription to a Data Exchange.
-
#revoke_subscription(name, revoke_subscription_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AnalyticshubV1::RevokeSubscriptionResponse
Revokes a given subscription.
-
#set_data_exchange_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AnalyticshubV1::Policy
Sets the IAM policy.
-
#set_listing_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AnalyticshubV1::Policy
Sets the IAM policy.
-
#set_subscription_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AnalyticshubV1::Policy
Sets the IAM policy.
-
#submit_query_template(name, submit_query_template_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AnalyticshubV1::QueryTemplate
Submits a query template for approval.
-
#subscribe_data_exchange(name, subscribe_data_exchange_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AnalyticshubV1::Operation
Creates a Subscription to a Data Clean Room.
-
#subscribe_listing(name, subscribe_listing_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AnalyticshubV1::SubscribeListingResponse
Subscribes to a listing.
-
#test_data_exchange_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AnalyticshubV1::TestIamPermissionsResponse
Returns the permissions that a caller has.
-
#test_listing_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AnalyticshubV1::TestIamPermissionsResponse
Returns the permissions that a caller has.
Constructor Details
#initialize ⇒ AnalyticsHubService
Returns a new instance of AnalyticsHubService.
47 48 49 50 51 52 |
# File 'lib/google/apis/analyticshub_v1/service.rb', line 47 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-analyticshub_v1', client_version: Google::Apis::AnalyticshubV1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
40 41 42 |
# File 'lib/google/apis/analyticshub_v1/service.rb', line 40 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
45 46 47 |
# File 'lib/google/apis/analyticshub_v1/service.rb', line 45 def quota_user @quota_user end |
Instance Method Details
#approve_query_template(name, approve_query_template_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AnalyticshubV1::QueryTemplate
Approves a query template.
840 841 842 843 844 845 846 847 848 849 850 |
# File 'lib/google/apis/analyticshub_v1/service.rb', line 840 def approve_query_template(name, approve_query_template_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:approve', ) command.request_representation = Google::Apis::AnalyticshubV1::ApproveQueryTemplateRequest::Representation command.request_object = approve_query_template_request_object command.response_representation = Google::Apis::AnalyticshubV1::QueryTemplate::Representation command.response_class = Google::Apis::AnalyticshubV1::QueryTemplate command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_data_exchange(parent, data_exchange_object = nil, data_exchange_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AnalyticshubV1::DataExchange
Creates a new data exchange.
117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/google/apis/analyticshub_v1/service.rb', line 117 def create_project_location_data_exchange(parent, data_exchange_object = nil, data_exchange_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/dataExchanges', ) command.request_representation = Google::Apis::AnalyticshubV1::DataExchange::Representation command.request_object = data_exchange_object command.response_representation = Google::Apis::AnalyticshubV1::DataExchange::Representation command.response_class = Google::Apis::AnalyticshubV1::DataExchange command.params['parent'] = parent unless parent.nil? command.query['dataExchangeId'] = data_exchange_id unless data_exchange_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_data_exchange_listing(parent, listing_object = nil, listing_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AnalyticshubV1::Listing
Creates a new listing.
477 478 479 480 481 482 483 484 485 486 487 488 |
# File 'lib/google/apis/analyticshub_v1/service.rb', line 477 def create_project_location_data_exchange_listing(parent, listing_object = nil, listing_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/listings', ) command.request_representation = Google::Apis::AnalyticshubV1::Listing::Representation command.request_object = listing_object command.response_representation = Google::Apis::AnalyticshubV1::Listing::Representation command.response_class = Google::Apis::AnalyticshubV1::Listing command.params['parent'] = parent unless parent.nil? command.query['listingId'] = listing_id unless listing_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_data_exchange_query_template(parent, query_template_object = nil, query_template_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AnalyticshubV1::QueryTemplate
Creates a new QueryTemplate
877 878 879 880 881 882 883 884 885 886 887 888 |
# File 'lib/google/apis/analyticshub_v1/service.rb', line 877 def create_project_location_data_exchange_query_template(parent, query_template_object = nil, query_template_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/queryTemplates', ) command.request_representation = Google::Apis::AnalyticshubV1::QueryTemplate::Representation command.request_object = query_template_object command.response_representation = Google::Apis::AnalyticshubV1::QueryTemplate::Representation command.response_class = Google::Apis::AnalyticshubV1::QueryTemplate command.params['parent'] = parent unless parent.nil? command.query['queryTemplateId'] = query_template_id unless query_template_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_data_exchange(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AnalyticshubV1::Empty
Deletes an existing data exchange.
151 152 153 154 155 156 157 158 159 |
# File 'lib/google/apis/analyticshub_v1/service.rb', line 151 def delete_project_location_data_exchange(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::AnalyticshubV1::Empty::Representation command.response_class = Google::Apis::AnalyticshubV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_data_exchange_listing(name, delete_commercial: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AnalyticshubV1::Empty
Deletes a listing.
515 516 517 518 519 520 521 522 523 524 |
# File 'lib/google/apis/analyticshub_v1/service.rb', line 515 def delete_project_location_data_exchange_listing(name, delete_commercial: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::AnalyticshubV1::Empty::Representation command.response_class = Google::Apis::AnalyticshubV1::Empty command.params['name'] = name unless name.nil? command.query['deleteCommercial'] = delete_commercial unless delete_commercial.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_data_exchange_query_template(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AnalyticshubV1::Empty
Deletes a query template.
911 912 913 914 915 916 917 918 919 |
# File 'lib/google/apis/analyticshub_v1/service.rb', line 911 def delete_project_location_data_exchange_query_template(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::AnalyticshubV1::Empty::Representation command.response_class = Google::Apis::AnalyticshubV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_subscription(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AnalyticshubV1::Operation
Deletes a subscription.
1085 1086 1087 1088 1089 1090 1091 1092 1093 |
# File 'lib/google/apis/analyticshub_v1/service.rb', line 1085 def delete_project_location_subscription(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::AnalyticshubV1::Operation::Representation command.response_class = Google::Apis::AnalyticshubV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_data_exchange_iam_policy(resource, get_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AnalyticshubV1::Policy
Gets the IAM policy.
215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/google/apis/analyticshub_v1/service.rb', line 215 def get_data_exchange_iam_policy(resource, get_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}:getIamPolicy', ) command.request_representation = Google::Apis::AnalyticshubV1::GetIamPolicyRequest::Representation command.request_object = get_iam_policy_request_object command.response_representation = Google::Apis::AnalyticshubV1::Policy::Representation command.response_class = Google::Apis::AnalyticshubV1::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_listing_iam_policy(resource, get_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AnalyticshubV1::Policy
Gets the IAM policy.
580 581 582 583 584 585 586 587 588 589 590 |
# File 'lib/google/apis/analyticshub_v1/service.rb', line 580 def get_listing_iam_policy(resource, get_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}:getIamPolicy', ) command.request_representation = Google::Apis::AnalyticshubV1::GetIamPolicyRequest::Representation command.request_object = get_iam_policy_request_object command.response_representation = Google::Apis::AnalyticshubV1::Policy::Representation command.response_class = Google::Apis::AnalyticshubV1::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_data_exchange(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AnalyticshubV1::DataExchange
Gets the details of a data exchange.
182 183 184 185 186 187 188 189 190 |
# File 'lib/google/apis/analyticshub_v1/service.rb', line 182 def get_project_location_data_exchange(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::AnalyticshubV1::DataExchange::Representation command.response_class = Google::Apis::AnalyticshubV1::DataExchange command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_data_exchange_listing(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AnalyticshubV1::Listing
Gets the details of a listing.
547 548 549 550 551 552 553 554 555 |
# File 'lib/google/apis/analyticshub_v1/service.rb', line 547 def get_project_location_data_exchange_listing(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::AnalyticshubV1::Listing::Representation command.response_class = Google::Apis::AnalyticshubV1::Listing command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_data_exchange_query_template(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AnalyticshubV1::QueryTemplate
Gets a QueryTemplate
942 943 944 945 946 947 948 949 950 |
# File 'lib/google/apis/analyticshub_v1/service.rb', line 942 def get_project_location_data_exchange_query_template(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::AnalyticshubV1::QueryTemplate::Representation command.response_class = Google::Apis::AnalyticshubV1::QueryTemplate command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_subscription(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AnalyticshubV1::Subscription
Gets the details of a Subscription.
1116 1117 1118 1119 1120 1121 1122 1123 1124 |
# File 'lib/google/apis/analyticshub_v1/service.rb', line 1116 def get_project_location_subscription(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::AnalyticshubV1::Subscription::Representation command.response_class = Google::Apis::AnalyticshubV1::Subscription command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_subscription_iam_policy(resource, get_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AnalyticshubV1::Policy
Gets the IAM policy.
1149 1150 1151 1152 1153 1154 1155 1156 1157 1158 1159 |
# File 'lib/google/apis/analyticshub_v1/service.rb', line 1149 def get_subscription_iam_policy(resource, get_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}:getIamPolicy', ) command.request_representation = Google::Apis::AnalyticshubV1::GetIamPolicyRequest::Representation command.request_object = get_iam_policy_request_object command.response_representation = Google::Apis::AnalyticshubV1::Policy::Representation command.response_class = Google::Apis::AnalyticshubV1::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_organization_location_data_exchanges(organization, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AnalyticshubV1::ListOrgDataExchangesResponse
Lists all data exchanges from projects in a given organization and location.
80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/google/apis/analyticshub_v1/service.rb', line 80 def list_organization_location_data_exchanges(organization, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+organization}/dataExchanges', ) command.response_representation = Google::Apis::AnalyticshubV1::ListOrgDataExchangesResponse::Representation command.response_class = Google::Apis::AnalyticshubV1::ListOrgDataExchangesResponse command.params['organization'] = organization unless organization.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_data_exchange_listing_subscriptions(resource, include_deleted_subscriptions: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AnalyticshubV1::ListSharedResourceSubscriptionsResponse
Lists all subscriptions on a given Data Exchange or Listing.
659 660 661 662 663 664 665 666 667 668 669 670 |
# File 'lib/google/apis/analyticshub_v1/service.rb', line 659 def list_project_location_data_exchange_listing_subscriptions(resource, include_deleted_subscriptions: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+resource}:listSubscriptions', ) command.response_representation = Google::Apis::AnalyticshubV1::ListSharedResourceSubscriptionsResponse::Representation command.response_class = Google::Apis::AnalyticshubV1::ListSharedResourceSubscriptionsResponse command.params['resource'] = resource unless resource.nil? command.query['includeDeletedSubscriptions'] = include_deleted_subscriptions unless include_deleted_subscriptions.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_data_exchange_listings(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AnalyticshubV1::ListListingsResponse
Lists all listings in a given project and location.
618 619 620 621 622 623 624 625 626 627 628 |
# File 'lib/google/apis/analyticshub_v1/service.rb', line 618 def list_project_location_data_exchange_listings(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/listings', ) command.response_representation = Google::Apis::AnalyticshubV1::ListListingsResponse::Representation command.response_class = Google::Apis::AnalyticshubV1::ListListingsResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_data_exchange_query_templates(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AnalyticshubV1::ListQueryTemplatesResponse
Lists all QueryTemplates in a given project and location.
979 980 981 982 983 984 985 986 987 988 989 |
# File 'lib/google/apis/analyticshub_v1/service.rb', line 979 def list_project_location_data_exchange_query_templates(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/queryTemplates', ) command.response_representation = Google::Apis::AnalyticshubV1::ListQueryTemplatesResponse::Representation command.response_class = Google::Apis::AnalyticshubV1::ListQueryTemplatesResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_data_exchange_subscriptions(resource, include_deleted_subscriptions: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AnalyticshubV1::ListSharedResourceSubscriptionsResponse
Lists all subscriptions on a given Data Exchange or Listing.
294 295 296 297 298 299 300 301 302 303 304 305 |
# File 'lib/google/apis/analyticshub_v1/service.rb', line 294 def list_project_location_data_exchange_subscriptions(resource, include_deleted_subscriptions: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+resource}:listSubscriptions', ) command.response_representation = Google::Apis::AnalyticshubV1::ListSharedResourceSubscriptionsResponse::Representation command.response_class = Google::Apis::AnalyticshubV1::ListSharedResourceSubscriptionsResponse command.params['resource'] = resource unless resource.nil? command.query['includeDeletedSubscriptions'] = include_deleted_subscriptions unless include_deleted_subscriptions.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_data_exchanges(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AnalyticshubV1::ListDataExchangesResponse
Lists all data exchanges in a given project and location.
253 254 255 256 257 258 259 260 261 262 263 |
# File 'lib/google/apis/analyticshub_v1/service.rb', line 253 def list_project_location_data_exchanges(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/dataExchanges', ) command.response_representation = Google::Apis::AnalyticshubV1::ListDataExchangesResponse::Representation command.response_class = Google::Apis::AnalyticshubV1::ListDataExchangesResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_subscriptions(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AnalyticshubV1::ListSubscriptionsResponse
Lists all subscriptions in a given project and location.
1195 1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 |
# File 'lib/google/apis/analyticshub_v1/service.rb', line 1195 def list_project_location_subscriptions(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/subscriptions', ) command.response_representation = Google::Apis::AnalyticshubV1::ListSubscriptionsResponse::Representation command.response_class = Google::Apis::AnalyticshubV1::ListSubscriptionsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_data_exchange(name, data_exchange_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AnalyticshubV1::DataExchange
Updates an existing data exchange.
333 334 335 336 337 338 339 340 341 342 343 344 |
# File 'lib/google/apis/analyticshub_v1/service.rb', line 333 def patch_project_location_data_exchange(name, data_exchange_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::AnalyticshubV1::DataExchange::Representation command.request_object = data_exchange_object command.response_representation = Google::Apis::AnalyticshubV1::DataExchange::Representation command.response_class = Google::Apis::AnalyticshubV1::DataExchange command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_data_exchange_listing(name, listing_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AnalyticshubV1::Listing
Updates an existing listing.
698 699 700 701 702 703 704 705 706 707 708 709 |
# File 'lib/google/apis/analyticshub_v1/service.rb', line 698 def patch_project_location_data_exchange_listing(name, listing_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::AnalyticshubV1::Listing::Representation command.request_object = listing_object command.response_representation = Google::Apis::AnalyticshubV1::Listing::Representation command.response_class = Google::Apis::AnalyticshubV1::Listing command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_data_exchange_query_template(name, query_template_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AnalyticshubV1::QueryTemplate
Updates an existing QueryTemplate
1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 |
# File 'lib/google/apis/analyticshub_v1/service.rb', line 1017 def patch_project_location_data_exchange_query_template(name, query_template_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::AnalyticshubV1::QueryTemplate::Representation command.request_object = query_template_object command.response_representation = Google::Apis::AnalyticshubV1::QueryTemplate::Representation command.response_class = Google::Apis::AnalyticshubV1::QueryTemplate command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#refresh_subscription(name, refresh_subscription_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AnalyticshubV1::Operation
Refreshes a Subscription to a Data Exchange. A Data Exchange can become stale when a publisher adds or removes data. This is a long-running operation as it may create many linked datasets.
1232 1233 1234 1235 1236 1237 1238 1239 1240 1241 1242 |
# File 'lib/google/apis/analyticshub_v1/service.rb', line 1232 def refresh_subscription(name, refresh_subscription_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:refresh', ) command.request_representation = Google::Apis::AnalyticshubV1::RefreshSubscriptionRequest::Representation command.request_object = refresh_subscription_request_object command.response_representation = Google::Apis::AnalyticshubV1::Operation::Representation command.response_class = Google::Apis::AnalyticshubV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#revoke_subscription(name, revoke_subscription_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AnalyticshubV1::RevokeSubscriptionResponse
Revokes a given subscription.
1266 1267 1268 1269 1270 1271 1272 1273 1274 1275 1276 |
# File 'lib/google/apis/analyticshub_v1/service.rb', line 1266 def revoke_subscription(name, revoke_subscription_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:revoke', ) command.request_representation = Google::Apis::AnalyticshubV1::RevokeSubscriptionRequest::Representation command.request_object = revoke_subscription_request_object command.response_representation = Google::Apis::AnalyticshubV1::RevokeSubscriptionResponse::Representation command.response_class = Google::Apis::AnalyticshubV1::RevokeSubscriptionResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#set_data_exchange_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AnalyticshubV1::Policy
Sets the IAM policy.
369 370 371 372 373 374 375 376 377 378 379 |
# File 'lib/google/apis/analyticshub_v1/service.rb', line 369 def set_data_exchange_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}:setIamPolicy', ) command.request_representation = Google::Apis::AnalyticshubV1::SetIamPolicyRequest::Representation command.request_object = set_iam_policy_request_object command.response_representation = Google::Apis::AnalyticshubV1::Policy::Representation command.response_class = Google::Apis::AnalyticshubV1::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#set_listing_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AnalyticshubV1::Policy
Sets the IAM policy.
734 735 736 737 738 739 740 741 742 743 744 |
# File 'lib/google/apis/analyticshub_v1/service.rb', line 734 def set_listing_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}:setIamPolicy', ) command.request_representation = Google::Apis::AnalyticshubV1::SetIamPolicyRequest::Representation command.request_object = set_iam_policy_request_object command.response_representation = Google::Apis::AnalyticshubV1::Policy::Representation command.response_class = Google::Apis::AnalyticshubV1::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#set_subscription_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AnalyticshubV1::Policy
Sets the IAM policy.
1301 1302 1303 1304 1305 1306 1307 1308 1309 1310 1311 |
# File 'lib/google/apis/analyticshub_v1/service.rb', line 1301 def set_subscription_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}:setIamPolicy', ) command.request_representation = Google::Apis::AnalyticshubV1::SetIamPolicyRequest::Representation command.request_object = set_iam_policy_request_object command.response_representation = Google::Apis::AnalyticshubV1::Policy::Representation command.response_class = Google::Apis::AnalyticshubV1::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#submit_query_template(name, submit_query_template_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AnalyticshubV1::QueryTemplate
Submits a query template for approval.
1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 |
# File 'lib/google/apis/analyticshub_v1/service.rb', line 1052 def submit_query_template(name, submit_query_template_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:submit', ) command.request_representation = Google::Apis::AnalyticshubV1::SubmitQueryTemplateRequest::Representation command.request_object = submit_query_template_request_object command.response_representation = Google::Apis::AnalyticshubV1::QueryTemplate::Representation command.response_class = Google::Apis::AnalyticshubV1::QueryTemplate command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#subscribe_data_exchange(name, subscribe_data_exchange_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AnalyticshubV1::Operation
Creates a Subscription to a Data Clean Room. This is a long-running operation as it will create one or more linked datasets. Throws a Bad Request error if the Data Exchange does not contain any listings.
405 406 407 408 409 410 411 412 413 414 415 |
# File 'lib/google/apis/analyticshub_v1/service.rb', line 405 def subscribe_data_exchange(name, subscribe_data_exchange_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:subscribe', ) command.request_representation = Google::Apis::AnalyticshubV1::SubscribeDataExchangeRequest::Representation command.request_object = subscribe_data_exchange_request_object command.response_representation = Google::Apis::AnalyticshubV1::Operation::Representation command.response_class = Google::Apis::AnalyticshubV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#subscribe_listing(name, subscribe_listing_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AnalyticshubV1::SubscribeListingResponse
Subscribes to a listing. Currently, with Analytics Hub, you can create listings that reference only BigQuery datasets. Upon subscription to a listing for a BigQuery dataset, Analytics Hub creates a linked dataset in the subscriber's project.
771 772 773 774 775 776 777 778 779 780 781 |
# File 'lib/google/apis/analyticshub_v1/service.rb', line 771 def subscribe_listing(name, subscribe_listing_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:subscribe', ) command.request_representation = Google::Apis::AnalyticshubV1::SubscribeListingRequest::Representation command.request_object = subscribe_listing_request_object command.response_representation = Google::Apis::AnalyticshubV1::SubscribeListingResponse::Representation command.response_class = Google::Apis::AnalyticshubV1::SubscribeListingResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#test_data_exchange_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AnalyticshubV1::TestIamPermissionsResponse
Returns the permissions that a caller has.
440 441 442 443 444 445 446 447 448 449 450 |
# File 'lib/google/apis/analyticshub_v1/service.rb', line 440 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}:testIamPermissions', ) command.request_representation = Google::Apis::AnalyticshubV1::TestIamPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::AnalyticshubV1::TestIamPermissionsResponse::Representation command.response_class = Google::Apis::AnalyticshubV1::TestIamPermissionsResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#test_listing_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AnalyticshubV1::TestIamPermissionsResponse
Returns the permissions that a caller has.
806 807 808 809 810 811 812 813 814 815 816 |
# File 'lib/google/apis/analyticshub_v1/service.rb', line 806 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}:testIamPermissions', ) command.request_representation = Google::Apis::AnalyticshubV1::TestIamPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::AnalyticshubV1::TestIamPermissionsResponse::Representation command.response_class = Google::Apis::AnalyticshubV1::TestIamPermissionsResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |