Class: Google::Apis::AnalyticshubV1::AvroConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/analyticshub_v1/classes.rb,
lib/google/apis/analyticshub_v1/representations.rb,
lib/google/apis/analyticshub_v1/representations.rb

Overview

Configuration for writing message data in Avro format. Message payloads and metadata will be written to files as an Avro binary.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AvroConfig

Returns a new instance of AvroConfig.



170
171
172
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 170

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#use_topic_schemaBoolean Also known as: use_topic_schema?

Optional. When true, the output Cloud Storage file will be serialized using the topic schema, if it exists. Corresponds to the JSON property useTopicSchema

Returns:

  • (Boolean)


157
158
159
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 157

def use_topic_schema
  @use_topic_schema
end

#write_metadataBoolean Also known as: write_metadata?

Optional. When true, write the subscription name, message_id, publish_time, attributes, and ordering_key as additional fields in the output. The subscription name, message_id, and publish_time fields are put in their own fields while all other message properties other than data (for example, an ordering_key, if present) are added as entries in the attributes map. Corresponds to the JSON property writeMetadata

Returns:

  • (Boolean)


167
168
169
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 167

def 
  @write_metadata
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



175
176
177
178
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 175

def update!(**args)
  @use_topic_schema = args[:use_topic_schema] if args.key?(:use_topic_schema)
  @write_metadata = args[:write_metadata] if args.key?(:write_metadata)
end