Class: Google::Apis::AnalyticshubV1::BigtableConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/analyticshub_v1/classes.rb,
lib/google/apis/analyticshub_v1/representations.rb,
lib/google/apis/analyticshub_v1/representations.rb

Overview

Configuration for a Bigtable subscription. The Pub/Sub message will be written to a Bigtable row as follows: - row key: subscription name and message ID delimited by #. - columns: message bytes written to a single column family " data" with an empty-string column qualifier. - cell timestamp: the message publish timestamp.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BigtableConfig

Returns a new instance of BigtableConfig.



346
347
348
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 346

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#app_profile_idString

Optional. The app profile to use for the Bigtable writes. If not specified, the "default" application profile will be used. The app profile must use single-cluster routing. Corresponds to the JSON property appProfileId

Returns:

  • (String)


317
318
319
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 317

def app_profile_id
  @app_profile_id
end

#service_account_emailString

Optional. The service account to use to write to Bigtable. The subscription creator or updater that specifies this field must have iam.serviceAccounts. actAs permission on the service account. If not specified, the Pub/Sub service agent, service-project_number@gcp-sa-pubsub.iam.gserviceaccount. com, is used. Corresponds to the JSON property serviceAccountEmail

Returns:

  • (String)


327
328
329
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 327

def 
  @service_account_email
end

#tableString

Optional. The unique name of the table to write messages to. Values are of the form projects//instances//tables/. Corresponds to the JSON property table

Returns:

  • (String)


333
334
335
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 333

def table
  @table
end

#write_metadataBoolean Also known as: write_metadata?

Optional. When true, write the subscription name, message_id, publish_time, attributes, and ordering_key to additional columns in the table under the pubsub_metadata column family. The subscription name, message_id, and publish_time fields are put in their own columns while all other message properties (other than data) are written to a JSON object in the attributes column. Corresponds to the JSON property writeMetadata

Returns:

  • (Boolean)


343
344
345
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 343

def 
  @write_metadata
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



351
352
353
354
355
356
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 351

def update!(**args)
  @app_profile_id = args[:app_profile_id] if args.key?(:app_profile_id)
  @service_account_email = args[:service_account_email] if args.key?(:service_account_email)
  @table = args[:table] if args.key?(:table)
  @write_metadata = args[:write_metadata] if args.key?(:write_metadata)
end