Class: Google::Apis::AnalyticshubV1::DataExchange
- Inherits:
-
Object
- Object
- Google::Apis::AnalyticshubV1::DataExchange
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/analyticshub_v1/classes.rb,
lib/google/apis/analyticshub_v1/representations.rb,
lib/google/apis/analyticshub_v1/representations.rb
Overview
A data exchange is a container that lets you share data. Along with the descriptive information about the data exchange, it contains listings that reference shared datasets.
Instance Attribute Summary collapse
-
#description ⇒ String
Optional.
-
#discovery_type ⇒ String
Optional.
-
#display_name ⇒ String
Required.
-
#documentation ⇒ String
Optional.
-
#icon ⇒ String
Optional.
-
#listing_count ⇒ Fixnum
Output only.
-
#log_linked_dataset_query_user_email ⇒ Boolean
(also: #log_linked_dataset_query_user_email?)
Optional.
-
#name ⇒ String
Output only.
-
#primary_contact ⇒ String
Optional.
-
#sharing_environment_config ⇒ Google::Apis::AnalyticshubV1::SharingEnvironmentConfig
Sharing environment is a behavior model for sharing data within a data exchange.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DataExchange
constructor
A new instance of DataExchange.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DataExchange
Returns a new instance of DataExchange.
629 630 631 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 629 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
Optional. Description of the data exchange. The description must not contain
Unicode non-characters as well as C0 and C1 control codes except tabs (HT),
new lines (LF), carriage returns (CR), and page breaks (FF). Default value is
an empty string. Max length: 2000 bytes.
Corresponds to the JSON property description
567 568 569 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 567 def description @description end |
#discovery_type ⇒ String
Optional. Type of discovery on the discovery page for all the listings under
this exchange. Updating this field also updates (overwrites) the
discovery_type field for all the listings under this exchange.
Corresponds to the JSON property discoveryType
574 575 576 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 574 def discovery_type @discovery_type end |
#display_name ⇒ String
Required. Human-readable display name of the data exchange. The display name
must contain only Unicode letters, numbers (0-9), underscores (_), dashes (-),
spaces ( ), ampersands (&) and must not start or end with spaces. Default
value is an empty string. Max length: 63 bytes.
Corresponds to the JSON property displayName
582 583 584 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 582 def display_name @display_name end |
#documentation ⇒ String
Optional. Documentation describing the data exchange.
Corresponds to the JSON property documentation
587 588 589 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 587 def documentation @documentation end |
#icon ⇒ String
Optional. Base64 encoded image representing the data exchange. Max Size: 3.
0MiB Expected image dimensions are 512x512 pixels, however the API only
performs validation on size of the encoded data. Note: For byte fields, the
content of the fields are base64-encoded (which increases the size of the data
by 33-36%) when using JSON on the wire.
Corresponds to the JSON property icon
NOTE: Values are automatically base64 encoded/decoded in the client library.
597 598 599 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 597 def icon @icon end |
#listing_count ⇒ Fixnum
Output only. Number of listings contained in the data exchange.
Corresponds to the JSON property listingCount
602 603 604 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 602 def listing_count @listing_count end |
#log_linked_dataset_query_user_email ⇒ Boolean Also known as: log_linked_dataset_query_user_email?
Optional. By default, false. If true, the DataExchange has an email sharing
mandate enabled.
Corresponds to the JSON property logLinkedDatasetQueryUserEmail
608 609 610 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 608 def log_linked_dataset_query_user_email @log_linked_dataset_query_user_email end |
#name ⇒ String
Output only. The resource name of the data exchange. e.g. projects/myproject/
locations/us/dataExchanges/123.
Corresponds to the JSON property name
615 616 617 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 615 def name @name end |
#primary_contact ⇒ String
Optional. Email or URL of the primary point of contact of the data exchange.
Max Length: 1000 bytes.
Corresponds to the JSON property primaryContact
621 622 623 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 621 def primary_contact @primary_contact end |
#sharing_environment_config ⇒ Google::Apis::AnalyticshubV1::SharingEnvironmentConfig
Sharing environment is a behavior model for sharing data within a data
exchange. This option is configurable for a data exchange.
Corresponds to the JSON property sharingEnvironmentConfig
627 628 629 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 627 def sharing_environment_config @sharing_environment_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
634 635 636 637 638 639 640 641 642 643 644 645 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 634 def update!(**args) @description = args[:description] if args.key?(:description) @discovery_type = args[:discovery_type] if args.key?(:discovery_type) @display_name = args[:display_name] if args.key?(:display_name) @documentation = args[:documentation] if args.key?(:documentation) @icon = args[:icon] if args.key?(:icon) @listing_count = args[:listing_count] if args.key?(:listing_count) @log_linked_dataset_query_user_email = args[:log_linked_dataset_query_user_email] if args.key?(:log_linked_dataset_query_user_email) @name = args[:name] if args.key?(:name) @primary_contact = args[:primary_contact] if args.key?(:primary_contact) @sharing_environment_config = args[:sharing_environment_config] if args.key?(:sharing_environment_config) end |