Class: Google::Apis::AnalyticshubV1::DcrExchangeConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/analyticshub_v1/classes.rb,
lib/google/apis/analyticshub_v1/representations.rb,
lib/google/apis/analyticshub_v1/representations.rb

Overview

Data Clean Room (DCR), used for privacy-safe and secured data sharing.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DcrExchangeConfig

Returns a new instance of DcrExchangeConfig.



698
699
700
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 698

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#single_linked_dataset_per_cleanroomBoolean Also known as: single_linked_dataset_per_cleanroom?

Output only. If True, when subscribing to this DCR, it will create only one linked dataset containing all resources shared within the cleanroom. If False, when subscribing to this DCR, it will create 1 linked dataset per listing. This is not configurable, and by default, all new DCRs will have the restriction set to True. Corresponds to the JSON property singleLinkedDatasetPerCleanroom

Returns:

  • (Boolean)


684
685
686
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 684

def single_linked_dataset_per_cleanroom
  @single_linked_dataset_per_cleanroom
end

#single_selected_resource_sharing_restrictionBoolean Also known as: single_selected_resource_sharing_restriction?

Output only. If True, this DCR restricts the contributors to sharing only a single resource in a Listing. And no two resources should have the same IDs. So if a contributor adds a view with a conflicting name, the CreateListing API will reject the request. if False, the data contributor can publish an entire dataset (as before). This is not configurable, and by default, all new DCRs will have the restriction set to True. Corresponds to the JSON property singleSelectedResourceSharingRestriction

Returns:

  • (Boolean)


695
696
697
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 695

def single_selected_resource_sharing_restriction
  @single_selected_resource_sharing_restriction
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



703
704
705
706
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 703

def update!(**args)
  @single_linked_dataset_per_cleanroom = args[:single_linked_dataset_per_cleanroom] if args.key?(:single_linked_dataset_per_cleanroom)
  @single_selected_resource_sharing_restriction = args[:single_selected_resource_sharing_restriction] if args.key?(:single_selected_resource_sharing_restriction)
end