Class: Google::Apis::AnalyticshubV1::ExpirationPolicy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/analyticshub_v1/classes.rb,
lib/google/apis/analyticshub_v1/representations.rb,
lib/google/apis/analyticshub_v1/representations.rb

Overview

A policy that specifies the conditions for resource expiration (i.e., automatic resource deletion).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExpirationPolicy

Returns a new instance of ExpirationPolicy.



923
924
925
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 923

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ttlString

Optional. Specifies the "time-to-live" duration for an associated resource. The resource expires if it is not active for a period of ttl. The definition of "activity" depends on the type of the associated resource. The minimum and maximum allowed values for ttl depend on the type of the associated resource, as well. If ttl is not set, the associated resource never expires. Corresponds to the JSON property ttl

Returns:

  • (String)


921
922
923
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 921

def ttl
  @ttl
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



928
929
930
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 928

def update!(**args)
  @ttl = args[:ttl] if args.key?(:ttl)
end