Class: Google::Apis::AnalyticshubV1::GoogleCloudBigqueryAnalyticshubV1ListingCommercialInfoGoogleCloudMarketplaceInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/analyticshub_v1/classes.rb,
lib/google/apis/analyticshub_v1/representations.rb,
lib/google/apis/analyticshub_v1/representations.rb

Overview

Specifies the details of the Marketplace Data Product associated with the Listing.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudBigqueryAnalyticshubV1ListingCommercialInfoGoogleCloudMarketplaceInfo

Returns a new instance of GoogleCloudBigqueryAnalyticshubV1ListingCommercialInfoGoogleCloudMarketplaceInfo.



1071
1072
1073
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1071

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#commercial_stateString

Output only. Commercial state of the Marketplace Data Product. Corresponds to the JSON property commercialState

Returns:

  • (String)


1063
1064
1065
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1063

def commercial_state
  @commercial_state
end

#serviceString

Output only. Resource name of the commercial service associated with the Marketplace Data Product. e.g. example.com Corresponds to the JSON property service

Returns:

  • (String)


1069
1070
1071
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1069

def service
  @service
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1076
1077
1078
1079
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1076

def update!(**args)
  @commercial_state = args[:commercial_state] if args.key?(:commercial_state)
  @service = args[:service] if args.key?(:service)
end