Class: Google::Apis::AnalyticshubV1::ListDataExchangesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/analyticshub_v1/classes.rb,
lib/google/apis/analyticshub_v1/representations.rb,
lib/google/apis/analyticshub_v1/representations.rb

Overview

Message for response to the list of data exchanges.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListDataExchangesResponse

Returns a new instance of ListDataExchangesResponse.



1393
1394
1395
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1393

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_exchangesArray<Google::Apis::AnalyticshubV1::DataExchange>

The list of data exchanges. Corresponds to the JSON property dataExchanges



1386
1387
1388
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1386

def data_exchanges
  @data_exchanges
end

#next_page_tokenString

A token to request the next page of results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1391
1392
1393
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1391

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1398
1399
1400
1401
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1398

def update!(**args)
  @data_exchanges = args[:data_exchanges] if args.key?(:data_exchanges)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end