Class: Google::Apis::AnalyticshubV1::ListQueryTemplatesResponse
- Inherits:
-
Object
- Object
- Google::Apis::AnalyticshubV1::ListQueryTemplatesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/analyticshub_v1/classes.rb,
lib/google/apis/analyticshub_v1/representations.rb,
lib/google/apis/analyticshub_v1/representations.rb
Overview
Message for response to the list of QueryTemplates.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token to request the next page of results.
-
#query_templates ⇒ Array<Google::Apis::AnalyticshubV1::QueryTemplate>
The list of QueryTemplates.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListQueryTemplatesResponse
constructor
A new instance of ListQueryTemplatesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListQueryTemplatesResponse
Returns a new instance of ListQueryTemplatesResponse.
1440 1441 1442 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1440 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token to request the next page of results.
Corresponds to the JSON property nextPageToken
1433 1434 1435 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1433 def next_page_token @next_page_token end |
#query_templates ⇒ Array<Google::Apis::AnalyticshubV1::QueryTemplate>
The list of QueryTemplates.
Corresponds to the JSON property queryTemplates
1438 1439 1440 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1438 def query_templates @query_templates end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1445 1446 1447 1448 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1445 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @query_templates = args[:query_templates] if args.key?(:query_templates) end |