Class: Google::Apis::AnalyticshubV1::MessageTransform

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/analyticshub_v1/classes.rb,
lib/google/apis/analyticshub_v1/representations.rb,
lib/google/apis/analyticshub_v1/representations.rb

Overview

All supported message transforms types.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MessageTransform

Returns a new instance of MessageTransform.



1725
1726
1727
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1725

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ai_inferenceGoogle::Apis::AnalyticshubV1::AiInference

Configuration for making inference requests against Vertex AI models. Corresponds to the JSON property aiInference



1697
1698
1699
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1697

def ai_inference
  @ai_inference
end

#compressionGoogle::Apis::AnalyticshubV1::Compression

Configuration for compressing/decompressing message data using a user- specified compression algorithm. Corresponds to the JSON property compression



1703
1704
1705
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1703

def compression
  @compression
end

#disabledBoolean Also known as: disabled?

Optional. If true, the transform is disabled and will not be applied to messages. Defaults to false. Corresponds to the JSON property disabled

Returns:

  • (Boolean)


1709
1710
1711
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1709

def disabled
  @disabled
end

#enabledBoolean Also known as: enabled?

Optional. This field is deprecated, use the disabled field to disable transforms. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


1716
1717
1718
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1716

def enabled
  @enabled
end

#javascript_udfGoogle::Apis::AnalyticshubV1::JavaScriptUdf

User-defined JavaScript function that can transform or filter a Pub/Sub message. Corresponds to the JSON property javascriptUdf



1723
1724
1725
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1723

def javascript_udf
  @javascript_udf
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1730
1731
1732
1733
1734
1735
1736
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1730

def update!(**args)
  @ai_inference = args[:ai_inference] if args.key?(:ai_inference)
  @compression = args[:compression] if args.key?(:compression)
  @disabled = args[:disabled] if args.key?(:disabled)
  @enabled = args[:enabled] if args.key?(:enabled)
  @javascript_udf = args[:javascript_udf] if args.key?(:javascript_udf)
end