Class: Google::Apis::AnalyticshubV1::Replica
- Inherits:
-
Object
- Object
- Google::Apis::AnalyticshubV1::Replica
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/analyticshub_v1/classes.rb,
lib/google/apis/analyticshub_v1/representations.rb,
lib/google/apis/analyticshub_v1/representations.rb
Overview
Represents the state of a replica of a shared dataset. It includes the geographic location of the replica and system-computed, output-only fields indicating its replication state and whether it is the primary replica.
Instance Attribute Summary collapse
-
#location ⇒ String
Output only.
-
#primary_state ⇒ String
Output only.
-
#replica_state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Replica
constructor
A new instance of Replica.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Replica
Returns a new instance of Replica.
2279 2280 2281 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2279 def initialize(**args) update!(**args) end |
Instance Attribute Details
#location ⇒ String
Output only. The geographic location where the replica resides. See BigQuery
locations for supported
locations. Eg. "us-central1".
Corresponds to the JSON property location
2266 2267 2268 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2266 def location @location end |
#primary_state ⇒ String
Output only. Indicates that this replica is the primary replica.
Corresponds to the JSON property primaryState
2271 2272 2273 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2271 def primary_state @primary_state end |
#replica_state ⇒ String
Output only. Assigned by Analytics Hub based on real BigQuery replication
state.
Corresponds to the JSON property replicaState
2277 2278 2279 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2277 def replica_state @replica_state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2284 2285 2286 2287 2288 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2284 def update!(**args) @location = args[:location] if args.key?(:location) @primary_state = args[:primary_state] if args.key?(:primary_state) @replica_state = args[:replica_state] if args.key?(:replica_state) end |