Class: Google::Apis::AnalyticshubV1::RestrictedExportPolicy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/analyticshub_v1/classes.rb,
lib/google/apis/analyticshub_v1/representations.rb,
lib/google/apis/analyticshub_v1/representations.rb

Overview

Restricted export policy used to configure restricted export on linked dataset.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RestrictedExportPolicy

Returns a new instance of RestrictedExportPolicy.



2319
2320
2321
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2319

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enabledBoolean Also known as: enabled?

Optional. If true, enable restricted export. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


2302
2303
2304
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2302

def enabled
  @enabled
end

#restrict_direct_table_accessBoolean Also known as: restrict_direct_table_access?

Optional. If true, restrict direct table access (read api/tabledata.list) on linked table. Corresponds to the JSON property restrictDirectTableAccess

Returns:

  • (Boolean)


2309
2310
2311
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2309

def restrict_direct_table_access
  @restrict_direct_table_access
end

#restrict_query_resultBoolean Also known as: restrict_query_result?

Optional. If true, restrict export of query result derived from restricted linked dataset table. Corresponds to the JSON property restrictQueryResult

Returns:

  • (Boolean)


2316
2317
2318
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2316

def restrict_query_result
  @restrict_query_result
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2324
2325
2326
2327
2328
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2324

def update!(**args)
  @enabled = args[:enabled] if args.key?(:enabled)
  @restrict_direct_table_access = args[:restrict_direct_table_access] if args.key?(:restrict_direct_table_access)
  @restrict_query_result = args[:restrict_query_result] if args.key?(:restrict_query_result)
end