Class: Google::Apis::AnalyticshubV1::RetryPolicy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/analyticshub_v1/classes.rb,
lib/google/apis/analyticshub_v1/representations.rb,
lib/google/apis/analyticshub_v1/representations.rb

Overview

A policy that specifies how Pub/Sub retries message delivery. Retry delay will be exponential based on provided minimum and maximum backoffs. https://en. wikipedia.org/wiki/Exponential_backoff. RetryPolicy will be triggered on NACKs or acknowledgement deadline exceeded events for a given message. Retry Policy is implemented on a best effort basis. At times, the delay between consecutive deliveries may not match the configuration. That is, delay can be more or less than configured backoff.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RetryPolicy

Returns a new instance of RetryPolicy.



2386
2387
2388
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2386

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#maximum_backoffString

Optional. The maximum delay between consecutive deliveries of a given message. Value should be between 0 and 600 seconds. Defaults to 600 seconds. Corresponds to the JSON property maximumBackoff

Returns:

  • (String)


2378
2379
2380
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2378

def maximum_backoff
  @maximum_backoff
end

#minimum_backoffString

Optional. The minimum delay between consecutive deliveries of a given message. Value should be between 0 and 600 seconds. Defaults to 10 seconds. Corresponds to the JSON property minimumBackoff

Returns:

  • (String)


2384
2385
2386
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2384

def minimum_backoff
  @minimum_backoff
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2391
2392
2393
2394
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2391

def update!(**args)
  @maximum_backoff = args[:maximum_backoff] if args.key?(:maximum_backoff)
  @minimum_backoff = args[:minimum_backoff] if args.key?(:minimum_backoff)
end