Class: Google::Apis::AnalyticshubV1::Subscription

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/analyticshub_v1/classes.rb,
lib/google/apis/analyticshub_v1/representations.rb,
lib/google/apis/analyticshub_v1/representations.rb

Overview

A subscription represents a subscribers' access to a particular set of published data. It contains references to associated listings, data exchanges, and linked datasets.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Subscription

Returns a new instance of Subscription.



2806
2807
2808
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2806

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#commercial_infoGoogle::Apis::AnalyticshubV1::GoogleCloudBigqueryAnalyticshubV1SubscriptionCommercialInfo

Commercial info metadata for this subscription. Corresponds to the JSON property commercialInfo



2725
2726
2727
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2725

def commercial_info
  @commercial_info
end

#creation_timeString

Output only. Timestamp when the subscription was created. Corresponds to the JSON property creationTime

Returns:

  • (String)


2730
2731
2732
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2730

def creation_time
  @creation_time
end

#data_exchangeString

Output only. Resource name of the source Data Exchange. e.g. projects/123/ locations/us/dataExchanges/456 Corresponds to the JSON property dataExchange

Returns:

  • (String)


2736
2737
2738
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2736

def data_exchange
  @data_exchange
end

#destination_datasetGoogle::Apis::AnalyticshubV1::DestinationDataset

Defines the destination bigquery dataset. Corresponds to the JSON property destinationDataset



2741
2742
2743
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2741

def destination_dataset
  @destination_dataset
end

#last_modify_timeString

Output only. Timestamp when the subscription was last modified. Corresponds to the JSON property lastModifyTime

Returns:

  • (String)


2746
2747
2748
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2746

def last_modify_time
  @last_modify_time
end

#linked_dataset_mapHash<String,Google::Apis::AnalyticshubV1::LinkedResource>

Output only. Map of listing resource names to associated linked resource, e.g. projects/123/locations/us/dataExchanges/456/listings/789 -> projects/123/ datasets/my_dataset For listing-level subscriptions, this is a map of size 1. Only contains values if state == STATE_ACTIVE. Corresponds to the JSON property linkedDatasetMap



2754
2755
2756
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2754

def linked_dataset_map
  @linked_dataset_map
end

#linked_resourcesArray<Google::Apis::AnalyticshubV1::LinkedResource>

Output only. Linked resources created in the subscription. Only contains values if state = STATE_ACTIVE. Corresponds to the JSON property linkedResources



2760
2761
2762
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2760

def linked_resources
  @linked_resources
end

#listingString

Output only. Resource name of the source Listing. e.g. projects/123/locations/ us/dataExchanges/456/listings/789 Corresponds to the JSON property listing

Returns:

  • (String)


2766
2767
2768
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2766

def listing
  @listing
end

#log_linked_dataset_query_user_emailBoolean Also known as: log_linked_dataset_query_user_email?

Output only. By default, false. If true, the Subscriber agreed to the email sharing mandate that is enabled for DataExchange/Listing. Corresponds to the JSON property logLinkedDatasetQueryUserEmail

Returns:

  • (Boolean)


2772
2773
2774
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2772

def log_linked_dataset_query_user_email
  @log_linked_dataset_query_user_email
end

#nameString

Output only. The resource name of the subscription. e.g. projects/myproject/ locations/us/subscriptions/123. Corresponds to the JSON property name

Returns:

  • (String)


2779
2780
2781
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2779

def name
  @name
end

#organization_display_nameString

Output only. Display name of the project of this subscription. Corresponds to the JSON property organizationDisplayName

Returns:

  • (String)


2784
2785
2786
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2784

def organization_display_name
  @organization_display_name
end

#organization_idString

Output only. Organization of the project this subscription belongs to. Corresponds to the JSON property organizationId

Returns:

  • (String)


2789
2790
2791
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2789

def organization_id
  @organization_id
end

#resource_typeString

Output only. Listing shared asset type. Corresponds to the JSON property resourceType

Returns:

  • (String)


2794
2795
2796
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2794

def resource_type
  @resource_type
end

#stateString

Output only. Current state of the subscription. Corresponds to the JSON property state

Returns:

  • (String)


2799
2800
2801
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2799

def state
  @state
end

#subscriber_contactString

Output only. Email of the subscriber. Corresponds to the JSON property subscriberContact

Returns:

  • (String)


2804
2805
2806
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2804

def subscriber_contact
  @subscriber_contact
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2811
2812
2813
2814
2815
2816
2817
2818
2819
2820
2821
2822
2823
2824
2825
2826
2827
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2811

def update!(**args)
  @commercial_info = args[:commercial_info] if args.key?(:commercial_info)
  @creation_time = args[:creation_time] if args.key?(:creation_time)
  @data_exchange = args[:data_exchange] if args.key?(:data_exchange)
  @destination_dataset = args[:destination_dataset] if args.key?(:destination_dataset)
  @last_modify_time = args[:last_modify_time] if args.key?(:last_modify_time)
  @linked_dataset_map = args[:linked_dataset_map] if args.key?(:linked_dataset_map)
  @linked_resources = args[:linked_resources] if args.key?(:linked_resources)
  @listing = args[:listing] if args.key?(:listing)
  @log_linked_dataset_query_user_email = args[:log_linked_dataset_query_user_email] if args.key?(:log_linked_dataset_query_user_email)
  @name = args[:name] if args.key?(:name)
  @organization_display_name = args[:organization_display_name] if args.key?(:organization_display_name)
  @organization_id = args[:organization_id] if args.key?(:organization_id)
  @resource_type = args[:resource_type] if args.key?(:resource_type)
  @state = args[:state] if args.key?(:state)
  @subscriber_contact = args[:subscriber_contact] if args.key?(:subscriber_contact)
end