Class: Google::Apis::AnalyticshubV1::BigQueryDatasetSource
- Inherits:
-
Object
- Object
- Google::Apis::AnalyticshubV1::BigQueryDatasetSource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/analyticshub_v1/classes.rb,
lib/google/apis/analyticshub_v1/representations.rb,
lib/google/apis/analyticshub_v1/representations.rb
Overview
A reference to a shared dataset. It is an existing BigQuery dataset with a collection of objects such as tables and views that you want to share with subscribers. When subscriber's subscribe to a listing, Analytics Hub creates a linked dataset in the subscriber's project. A Linked dataset is an opaque, read-only BigQuery dataset that serves as a symbolic link to a shared dataset.
Instance Attribute Summary collapse
-
#dataset ⇒ String
Optional.
-
#effective_replicas ⇒ Array<Google::Apis::AnalyticshubV1::Replica>
Output only.
-
#replica_locations ⇒ Array<String>
Optional.
-
#restricted_export_policy ⇒ Google::Apis::AnalyticshubV1::RestrictedExportPolicy
Restricted export policy used to configure restricted export on linked dataset.
-
#selected_resources ⇒ Array<Google::Apis::AnalyticshubV1::SelectedResource>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BigQueryDatasetSource
constructor
A new instance of BigQueryDatasetSource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BigQueryDatasetSource
Returns a new instance of BigQueryDatasetSource.
290 291 292 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 290 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dataset ⇒ String
Optional. Resource name of the dataset source for this listing. e.g. projects/
myproject/datasets/123
Corresponds to the JSON property dataset
264 265 266 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 264 def dataset @dataset end |
#effective_replicas ⇒ Array<Google::Apis::AnalyticshubV1::Replica>
Output only. Server-owned effective state of replicas. Contains both primary
and secondary replicas. Each replica includes a system-computed (output-only)
state and primary designation.
Corresponds to the JSON property effectiveReplicas
271 272 273 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 271 def effective_replicas @effective_replicas end |
#replica_locations ⇒ Array<String>
Optional. A list of regions where the publisher has created shared dataset
replicas.
Corresponds to the JSON property replicaLocations
277 278 279 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 277 def replica_locations @replica_locations end |
#restricted_export_policy ⇒ Google::Apis::AnalyticshubV1::RestrictedExportPolicy
Restricted export policy used to configure restricted export on linked dataset.
Corresponds to the JSON property restrictedExportPolicy
282 283 284 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 282 def restricted_export_policy @restricted_export_policy end |
#selected_resources ⇒ Array<Google::Apis::AnalyticshubV1::SelectedResource>
Optional. Resource in this dataset that is selectively shared. This field is
required for data clean room exchanges.
Corresponds to the JSON property selectedResources
288 289 290 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 288 def selected_resources @selected_resources end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
295 296 297 298 299 300 301 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 295 def update!(**args) @dataset = args[:dataset] if args.key?(:dataset) @effective_replicas = args[:effective_replicas] if args.key?(:effective_replicas) @replica_locations = args[:replica_locations] if args.key?(:replica_locations) @restricted_export_policy = args[:restricted_export_policy] if args.key?(:restricted_export_policy) @selected_resources = args[:selected_resources] if args.key?(:selected_resources) end |