Class: Google::Apis::AnalyticshubV1::DestinationPubSubSubscription

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/analyticshub_v1/classes.rb,
lib/google/apis/analyticshub_v1/representations.rb,
lib/google/apis/analyticshub_v1/representations.rb

Overview

Defines the destination Pub/Sub subscription.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DestinationPubSubSubscription

Returns a new instance of DestinationPubSubSubscription.



857
858
859
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 857

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#pubsub_subscriptionGoogle::Apis::AnalyticshubV1::GooglePubsubV1Subscription

Defines the destination Pub/Sub subscription. If none of push_config, bigquery_config, cloud_storage_config, bigtable_config, pubsub_export_config, or pubsublite_export_config is set, then the subscriber will pull and ack messages using API methods. At most one of these fields may be set. Corresponds to the JSON property pubsubSubscription



855
856
857
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 855

def pubsub_subscription
  @pubsub_subscription
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



862
863
864
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 862

def update!(**args)
  @pubsub_subscription = args[:pubsub_subscription] if args.key?(:pubsub_subscription)
end