Class: Google::Apis::AnalyticshubV1::GoogleCloudBigqueryAnalyticshubV1ListingCommercialInfoGoogleCloudMarketplaceInfo
- Inherits:
-
Object
- Object
- Google::Apis::AnalyticshubV1::GoogleCloudBigqueryAnalyticshubV1ListingCommercialInfoGoogleCloudMarketplaceInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/analyticshub_v1/classes.rb,
lib/google/apis/analyticshub_v1/representations.rb,
lib/google/apis/analyticshub_v1/representations.rb
Overview
Specifies the details of the Marketplace Data Product associated with the Listing.
Instance Attribute Summary collapse
-
#commercial_state ⇒ String
Output only.
-
#service ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudBigqueryAnalyticshubV1ListingCommercialInfoGoogleCloudMarketplaceInfo
constructor
A new instance of GoogleCloudBigqueryAnalyticshubV1ListingCommercialInfoGoogleCloudMarketplaceInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudBigqueryAnalyticshubV1ListingCommercialInfoGoogleCloudMarketplaceInfo
Returns a new instance of GoogleCloudBigqueryAnalyticshubV1ListingCommercialInfoGoogleCloudMarketplaceInfo.
1044 1045 1046 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1044 def initialize(**args) update!(**args) end |
Instance Attribute Details
#commercial_state ⇒ String
Output only. Commercial state of the Marketplace Data Product.
Corresponds to the JSON property commercialState
1036 1037 1038 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1036 def commercial_state @commercial_state end |
#service ⇒ String
Output only. Resource name of the commercial service associated with the
Marketplace Data Product. e.g. example.com
Corresponds to the JSON property service
1042 1043 1044 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1042 def service @service end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1049 1050 1051 1052 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1049 def update!(**args) @commercial_state = args[:commercial_state] if args.key?(:commercial_state) @service = args[:service] if args.key?(:service) end |