Class: Google::Apis::AnalyticshubV1::Listing
- Inherits:
-
Object
- Object
- Google::Apis::AnalyticshubV1::Listing
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/analyticshub_v1/classes.rb,
lib/google/apis/analyticshub_v1/representations.rb,
lib/google/apis/analyticshub_v1/representations.rb
Overview
A listing is what gets published into a data exchange that a subscriber can subscribe to. It contains a reference to the data source along with descriptive information that will help subscribers find and subscribe the data.
Instance Attribute Summary collapse
-
#allow_only_metadata_sharing ⇒ Boolean
(also: #allow_only_metadata_sharing?)
Optional.
-
#bigquery_dataset ⇒ Google::Apis::AnalyticshubV1::BigQueryDatasetSource
A reference to a shared dataset.
-
#categories ⇒ Array<String>
Optional.
-
#commercial_info ⇒ Google::Apis::AnalyticshubV1::GoogleCloudBigqueryAnalyticshubV1ListingCommercialInfo
Commercial info contains the information about the commercial data products associated with the listing.
-
#data_provider ⇒ Google::Apis::AnalyticshubV1::DataProvider
Contains details of the data provider.
-
#description ⇒ String
Optional.
-
#discovery_type ⇒ String
Optional.
-
#display_name ⇒ String
Required.
-
#documentation ⇒ String
Optional.
-
#icon ⇒ String
Optional.
-
#log_linked_dataset_query_user_email ⇒ Boolean
(also: #log_linked_dataset_query_user_email?)
Optional.
-
#name ⇒ String
Output only.
-
#primary_contact ⇒ String
Optional.
-
#publisher ⇒ Google::Apis::AnalyticshubV1::Publisher
Contains details of the listing publisher.
-
#pubsub_topic ⇒ Google::Apis::AnalyticshubV1::PubSubTopicSource
Pub/Sub topic source.
-
#request_access ⇒ String
Optional.
-
#resource_type ⇒ String
Output only.
-
#restricted_export_config ⇒ Google::Apis::AnalyticshubV1::RestrictedExportConfig
Restricted export config, used to configure restricted export on linked dataset.
-
#state ⇒ String
Output only.
-
#stored_procedure_config ⇒ Google::Apis::AnalyticshubV1::StoredProcedureConfig
Stored procedure configuration, used to configure stored procedure sharing on linked dataset.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Listing
constructor
A new instance of Listing.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Listing
Returns a new instance of Listing.
1661 1662 1663 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1661 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allow_only_metadata_sharing ⇒ Boolean Also known as: allow_only_metadata_sharing?
Optional. If true, the listing is only available to get the resource metadata.
Listing is non subscribable.
Corresponds to the JSON property allowOnlyMetadataSharing
1539 1540 1541 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1539 def @allow_only_metadata_sharing end |
#bigquery_dataset ⇒ Google::Apis::AnalyticshubV1::BigQueryDatasetSource
A reference to a shared dataset. It is an existing BigQuery dataset with a
collection of objects such as tables and views that you want to share with
subscribers. When subscriber's subscribe to a listing, Analytics Hub creates a
linked dataset in the subscriber's project. A Linked dataset is an opaque,
read-only BigQuery dataset that serves as a symbolic link to a shared
dataset.
Corresponds to the JSON property bigqueryDataset
1550 1551 1552 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1550 def bigquery_dataset @bigquery_dataset end |
#categories ⇒ Array<String>
Optional. Categories of the listing. Up to five categories are allowed.
Corresponds to the JSON property categories
1555 1556 1557 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1555 def categories @categories end |
#commercial_info ⇒ Google::Apis::AnalyticshubV1::GoogleCloudBigqueryAnalyticshubV1ListingCommercialInfo
Commercial info contains the information about the commercial data products
associated with the listing.
Corresponds to the JSON property commercialInfo
1561 1562 1563 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1561 def commercial_info @commercial_info end |
#data_provider ⇒ Google::Apis::AnalyticshubV1::DataProvider
Contains details of the data provider.
Corresponds to the JSON property dataProvider
1566 1567 1568 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1566 def data_provider @data_provider end |
#description ⇒ String
Optional. Short description of the listing. The description must not contain
Unicode non-characters and C0 and C1 control codes except tabs (HT), new lines
(LF), carriage returns (CR), and page breaks (FF). Default value is an empty
string. Max length: 2000 bytes.
Corresponds to the JSON property description
1574 1575 1576 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1574 def description @description end |
#discovery_type ⇒ String
Optional. Type of discovery of the listing on the discovery page.
Corresponds to the JSON property discoveryType
1579 1580 1581 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1579 def discovery_type @discovery_type end |
#display_name ⇒ String
Required. Human-readable display name of the listing. The display name must
contain only Unicode letters, numbers (0-9), underscores (_), dashes (-),
spaces ( ), ampersands (&) and can't start or end with spaces. Default value
is an empty string. Max length: 63 bytes.
Corresponds to the JSON property displayName
1587 1588 1589 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1587 def display_name @display_name end |
#documentation ⇒ String
Optional. Documentation describing the listing.
Corresponds to the JSON property documentation
1592 1593 1594 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1592 def documentation @documentation end |
#icon ⇒ String
Optional. Base64 encoded image representing the listing. Max Size: 3.0MiB
Expected image dimensions are 512x512 pixels, however the API only performs
validation on size of the encoded data. Note: For byte fields, the contents of
the field are base64-encoded (which increases the size of the data by 33-36%)
when using JSON on the wire.
Corresponds to the JSON property icon
NOTE: Values are automatically base64 encoded/decoded in the client library.
1602 1603 1604 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1602 def icon @icon end |
#log_linked_dataset_query_user_email ⇒ Boolean Also known as: log_linked_dataset_query_user_email?
Optional. By default, false. If true, the Listing has an email sharing mandate
enabled.
Corresponds to the JSON property logLinkedDatasetQueryUserEmail
1608 1609 1610 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1608 def log_linked_dataset_query_user_email @log_linked_dataset_query_user_email end |
#name ⇒ String
Output only. The resource name of the listing. e.g. projects/myproject/
locations/us/dataExchanges/123/listings/456
Corresponds to the JSON property name
1615 1616 1617 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1615 def name @name end |
#primary_contact ⇒ String
Optional. Email or URL of the primary point of contact of the listing. Max
Length: 1000 bytes.
Corresponds to the JSON property primaryContact
1621 1622 1623 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1621 def primary_contact @primary_contact end |
#publisher ⇒ Google::Apis::AnalyticshubV1::Publisher
Contains details of the listing publisher.
Corresponds to the JSON property publisher
1626 1627 1628 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1626 def publisher @publisher end |
#pubsub_topic ⇒ Google::Apis::AnalyticshubV1::PubSubTopicSource
Pub/Sub topic source.
Corresponds to the JSON property pubsubTopic
1631 1632 1633 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1631 def pubsub_topic @pubsub_topic end |
#request_access ⇒ String
Optional. Email or URL of the request access of the listing. Subscribers can
use this reference to request access. Max Length: 1000 bytes.
Corresponds to the JSON property requestAccess
1637 1638 1639 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1637 def request_access @request_access end |
#resource_type ⇒ String
Output only. Listing shared asset type.
Corresponds to the JSON property resourceType
1642 1643 1644 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1642 def resource_type @resource_type end |
#restricted_export_config ⇒ Google::Apis::AnalyticshubV1::RestrictedExportConfig
Restricted export config, used to configure restricted export on linked
dataset.
Corresponds to the JSON property restrictedExportConfig
1648 1649 1650 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1648 def restricted_export_config @restricted_export_config end |
#state ⇒ String
Output only. Current state of the listing.
Corresponds to the JSON property state
1653 1654 1655 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1653 def state @state end |
#stored_procedure_config ⇒ Google::Apis::AnalyticshubV1::StoredProcedureConfig
Stored procedure configuration, used to configure stored procedure sharing on
linked dataset.
Corresponds to the JSON property storedProcedureConfig
1659 1660 1661 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1659 def stored_procedure_config @stored_procedure_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1666 1667 1668 1669 1670 1671 1672 1673 1674 1675 1676 1677 1678 1679 1680 1681 1682 1683 1684 1685 1686 1687 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1666 def update!(**args) @allow_only_metadata_sharing = args[:allow_only_metadata_sharing] if args.key?(:allow_only_metadata_sharing) @bigquery_dataset = args[:bigquery_dataset] if args.key?(:bigquery_dataset) @categories = args[:categories] if args.key?(:categories) @commercial_info = args[:commercial_info] if args.key?(:commercial_info) @data_provider = args[:data_provider] if args.key?(:data_provider) @description = args[:description] if args.key?(:description) @discovery_type = args[:discovery_type] if args.key?(:discovery_type) @display_name = args[:display_name] if args.key?(:display_name) @documentation = args[:documentation] if args.key?(:documentation) @icon = args[:icon] if args.key?(:icon) @log_linked_dataset_query_user_email = args[:log_linked_dataset_query_user_email] if args.key?(:log_linked_dataset_query_user_email) @name = args[:name] if args.key?(:name) @primary_contact = args[:primary_contact] if args.key?(:primary_contact) @publisher = args[:publisher] if args.key?(:publisher) @pubsub_topic = args[:pubsub_topic] if args.key?(:pubsub_topic) @request_access = args[:request_access] if args.key?(:request_access) @resource_type = args[:resource_type] if args.key?(:resource_type) @restricted_export_config = args[:restricted_export_config] if args.key?(:restricted_export_config) @state = args[:state] if args.key?(:state) @stored_procedure_config = args[:stored_procedure_config] if args.key?(:stored_procedure_config) end |