Class: Google::Apis::AnalyticshubV1::Listing

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/analyticshub_v1/classes.rb,
lib/google/apis/analyticshub_v1/representations.rb,
lib/google/apis/analyticshub_v1/representations.rb

Overview

A listing is what gets published into a data exchange that a subscriber can subscribe to. It contains a reference to the data source along with descriptive information that will help subscribers find and subscribe the data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Listing

Returns a new instance of Listing.



1635
1636
1637
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1635

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allow_only_metadata_sharingBoolean Also known as: allow_only_metadata_sharing?

Optional. If true, the listing is only available to get the resource metadata. Listing is non subscribable. Corresponds to the JSON property allowOnlyMetadataSharing

Returns:

  • (Boolean)


1513
1514
1515
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1513

def 
  @allow_only_metadata_sharing
end

#bigquery_datasetGoogle::Apis::AnalyticshubV1::BigQueryDatasetSource

A reference to a shared dataset. It is an existing BigQuery dataset with a collection of objects such as tables and views that you want to share with subscribers. When subscriber's subscribe to a listing, Analytics Hub creates a linked dataset in the subscriber's project. A Linked dataset is an opaque, read-only BigQuery dataset that serves as a symbolic link to a shared dataset. Corresponds to the JSON property bigqueryDataset



1524
1525
1526
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1524

def bigquery_dataset
  @bigquery_dataset
end

#categoriesArray<String>

Optional. Categories of the listing. Up to five categories are allowed. Corresponds to the JSON property categories

Returns:

  • (Array<String>)


1529
1530
1531
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1529

def categories
  @categories
end

#commercial_infoGoogle::Apis::AnalyticshubV1::GoogleCloudBigqueryAnalyticshubV1ListingCommercialInfo

Commercial info contains the information about the commercial data products associated with the listing. Corresponds to the JSON property commercialInfo



1535
1536
1537
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1535

def commercial_info
  @commercial_info
end

#data_providerGoogle::Apis::AnalyticshubV1::DataProvider

Contains details of the data provider. Corresponds to the JSON property dataProvider



1540
1541
1542
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1540

def data_provider
  @data_provider
end

#descriptionString

Optional. Short description of the listing. The description must not contain Unicode non-characters and C0 and C1 control codes except tabs (HT), new lines (LF), carriage returns (CR), and page breaks (FF). Default value is an empty string. Max length: 2000 bytes. Corresponds to the JSON property description

Returns:

  • (String)


1548
1549
1550
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1548

def description
  @description
end

#discovery_typeString

Optional. Type of discovery of the listing on the discovery page. Corresponds to the JSON property discoveryType

Returns:

  • (String)


1553
1554
1555
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1553

def discovery_type
  @discovery_type
end

#display_nameString

Required. Human-readable display name of the listing. The display name must contain only Unicode letters, numbers (0-9), underscores (_), dashes (-), spaces ( ), ampersands (&) and can't start or end with spaces. Default value is an empty string. Max length: 63 bytes. Corresponds to the JSON property displayName

Returns:

  • (String)


1561
1562
1563
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1561

def display_name
  @display_name
end

#documentationString

Optional. Documentation describing the listing. Corresponds to the JSON property documentation

Returns:

  • (String)


1566
1567
1568
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1566

def documentation
  @documentation
end

#iconString

Optional. Base64 encoded image representing the listing. Max Size: 3.0MiB Expected image dimensions are 512x512 pixels, however the API only performs validation on size of the encoded data. Note: For byte fields, the contents of the field are base64-encoded (which increases the size of the data by 33-36%) when using JSON on the wire. Corresponds to the JSON property icon NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


1576
1577
1578
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1576

def icon
  @icon
end

#log_linked_dataset_query_user_emailBoolean Also known as: log_linked_dataset_query_user_email?

Optional. By default, false. If true, the Listing has an email sharing mandate enabled. Corresponds to the JSON property logLinkedDatasetQueryUserEmail

Returns:

  • (Boolean)


1582
1583
1584
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1582

def log_linked_dataset_query_user_email
  @log_linked_dataset_query_user_email
end

#nameString

Output only. The resource name of the listing. e.g. projects/myproject/ locations/us/dataExchanges/123/listings/456 Corresponds to the JSON property name

Returns:

  • (String)


1589
1590
1591
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1589

def name
  @name
end

#primary_contactString

Optional. Email or URL of the primary point of contact of the listing. Max Length: 1000 bytes. Corresponds to the JSON property primaryContact

Returns:

  • (String)


1595
1596
1597
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1595

def primary_contact
  @primary_contact
end

#publisherGoogle::Apis::AnalyticshubV1::Publisher

Contains details of the listing publisher. Corresponds to the JSON property publisher



1600
1601
1602
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1600

def publisher
  @publisher
end

#pubsub_topicGoogle::Apis::AnalyticshubV1::PubSubTopicSource

Pub/Sub topic source. Corresponds to the JSON property pubsubTopic



1605
1606
1607
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1605

def pubsub_topic
  @pubsub_topic
end

#request_accessString

Optional. Email or URL of the request access of the listing. Subscribers can use this reference to request access. Max Length: 1000 bytes. Corresponds to the JSON property requestAccess

Returns:

  • (String)


1611
1612
1613
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1611

def request_access
  @request_access
end

#resource_typeString

Output only. Listing shared asset type. Corresponds to the JSON property resourceType

Returns:

  • (String)


1616
1617
1618
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1616

def resource_type
  @resource_type
end

#restricted_export_configGoogle::Apis::AnalyticshubV1::RestrictedExportConfig

Restricted export config, used to configure restricted export on linked dataset. Corresponds to the JSON property restrictedExportConfig



1622
1623
1624
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1622

def restricted_export_config
  @restricted_export_config
end

#stateString

Output only. Current state of the listing. Corresponds to the JSON property state

Returns:

  • (String)


1627
1628
1629
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1627

def state
  @state
end

#stored_procedure_configGoogle::Apis::AnalyticshubV1::StoredProcedureConfig

Stored procedure configuration, used to configure stored procedure sharing on linked dataset. Corresponds to the JSON property storedProcedureConfig



1633
1634
1635
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1633

def stored_procedure_config
  @stored_procedure_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1640
1641
1642
1643
1644
1645
1646
1647
1648
1649
1650
1651
1652
1653
1654
1655
1656
1657
1658
1659
1660
1661
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1640

def update!(**args)
  @allow_only_metadata_sharing = args[:allow_only_metadata_sharing] if args.key?(:allow_only_metadata_sharing)
  @bigquery_dataset = args[:bigquery_dataset] if args.key?(:bigquery_dataset)
  @categories = args[:categories] if args.key?(:categories)
  @commercial_info = args[:commercial_info] if args.key?(:commercial_info)
  @data_provider = args[:data_provider] if args.key?(:data_provider)
  @description = args[:description] if args.key?(:description)
  @discovery_type = args[:discovery_type] if args.key?(:discovery_type)
  @display_name = args[:display_name] if args.key?(:display_name)
  @documentation = args[:documentation] if args.key?(:documentation)
  @icon = args[:icon] if args.key?(:icon)
  @log_linked_dataset_query_user_email = args[:log_linked_dataset_query_user_email] if args.key?(:log_linked_dataset_query_user_email)
  @name = args[:name] if args.key?(:name)
  @primary_contact = args[:primary_contact] if args.key?(:primary_contact)
  @publisher = args[:publisher] if args.key?(:publisher)
  @pubsub_topic = args[:pubsub_topic] if args.key?(:pubsub_topic)
  @request_access = args[:request_access] if args.key?(:request_access)
  @resource_type = args[:resource_type] if args.key?(:resource_type)
  @restricted_export_config = args[:restricted_export_config] if args.key?(:restricted_export_config)
  @state = args[:state] if args.key?(:state)
  @stored_procedure_config = args[:stored_procedure_config] if args.key?(:stored_procedure_config)
end