Class: Google::Apis::AnalyticshubV1::MessageTransform

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/analyticshub_v1/classes.rb,
lib/google/apis/analyticshub_v1/representations.rb,
lib/google/apis/analyticshub_v1/representations.rb

Overview

All supported message transforms types.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MessageTransform

Returns a new instance of MessageTransform.



1691
1692
1693
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1691

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ai_inferenceGoogle::Apis::AnalyticshubV1::AiInference

Configuration for making inference requests against Vertex AI models. Corresponds to the JSON property aiInference



1669
1670
1671
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1669

def ai_inference
  @ai_inference
end

#disabledBoolean Also known as: disabled?

Optional. If true, the transform is disabled and will not be applied to messages. Defaults to false. Corresponds to the JSON property disabled

Returns:

  • (Boolean)


1675
1676
1677
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1675

def disabled
  @disabled
end

#enabledBoolean Also known as: enabled?

Optional. This field is deprecated, use the disabled field to disable transforms. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


1682
1683
1684
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1682

def enabled
  @enabled
end

#javascript_udfGoogle::Apis::AnalyticshubV1::JavaScriptUdf

User-defined JavaScript function that can transform or filter a Pub/Sub message. Corresponds to the JSON property javascriptUdf



1689
1690
1691
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1689

def javascript_udf
  @javascript_udf
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1696
1697
1698
1699
1700
1701
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 1696

def update!(**args)
  @ai_inference = args[:ai_inference] if args.key?(:ai_inference)
  @disabled = args[:disabled] if args.key?(:disabled)
  @enabled = args[:enabled] if args.key?(:enabled)
  @javascript_udf = args[:javascript_udf] if args.key?(:javascript_udf)
end