Class: Google::Apis::AnalyticshubV1::PushConfig
- Inherits:
-
Object
- Object
- Google::Apis::AnalyticshubV1::PushConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/analyticshub_v1/classes.rb,
lib/google/apis/analyticshub_v1/representations.rb,
lib/google/apis/analyticshub_v1/representations.rb
Overview
Configuration for a push delivery endpoint.
Instance Attribute Summary collapse
-
#attributes ⇒ Hash<String,String>
Optional.
-
#no_wrapper ⇒ Google::Apis::AnalyticshubV1::NoWrapper
Sets the
datafield as the HTTP body for delivery. -
#oidc_token ⇒ Google::Apis::AnalyticshubV1::OidcToken
Contains information needed for generating an OpenID Connect token.
-
#pubsub_wrapper ⇒ Google::Apis::AnalyticshubV1::PubsubWrapper
The payload to the push endpoint is in the form of the JSON representation of a PubsubMessage (https://cloud.google.com/pubsub/docs/reference/rpc/google. pubsub.v1#pubsubmessage).
-
#push_endpoint ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PushConfig
constructor
A new instance of PushConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PushConfig
Returns a new instance of PushConfig.
2091 2092 2093 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2091 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attributes ⇒ Hash<String,String>
Optional. Endpoint configuration attributes that can be used to control
different aspects of the message delivery. The only currently supported
attribute is x-goog-version, which you can use to change the format of the
pushed message. This attribute indicates the version of the data expected by
the endpoint. This controls the shape of the pushed message (i.e., its fields
and metadata). If not present during the CreateSubscription call, it will
default to the version of the Pub/Sub API used to make such call. If not
present in a ModifyPushConfig call, its value will not be changed.
GetSubscription calls will always return a valid version, even if the
subscription was created without this attribute. The only supported values for
the x-goog-version attribute are: * v1beta1: uses the push format defined
in the v1beta1 Pub/Sub API. * v1 or v1beta2: uses the push format defined
in the v1 Pub/Sub API. For example: attributes "x-goog-version": "v1" `
Corresponds to the JSON propertyattributes`
2065 2066 2067 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2065 def attributes @attributes end |
#no_wrapper ⇒ Google::Apis::AnalyticshubV1::NoWrapper
Sets the data field as the HTTP body for delivery.
Corresponds to the JSON property noWrapper
2070 2071 2072 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2070 def no_wrapper @no_wrapper end |
#oidc_token ⇒ Google::Apis::AnalyticshubV1::OidcToken
Contains information needed for generating an OpenID Connect token.
Corresponds to the JSON property oidcToken
2076 2077 2078 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2076 def oidc_token @oidc_token end |
#pubsub_wrapper ⇒ Google::Apis::AnalyticshubV1::PubsubWrapper
The payload to the push endpoint is in the form of the JSON representation of
a PubsubMessage (https://cloud.google.com/pubsub/docs/reference/rpc/google.
pubsub.v1#pubsubmessage).
Corresponds to the JSON property pubsubWrapper
2083 2084 2085 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2083 def pubsub_wrapper @pubsub_wrapper end |
#push_endpoint ⇒ String
Optional. A URL locating the endpoint to which messages should be pushed. For
example, a Webhook endpoint might use https://example.com/push.
Corresponds to the JSON property pushEndpoint
2089 2090 2091 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2089 def push_endpoint @push_endpoint end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2096 2097 2098 2099 2100 2101 2102 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2096 def update!(**args) @attributes = args[:attributes] if args.key?(:attributes) @no_wrapper = args[:no_wrapper] if args.key?(:no_wrapper) @oidc_token = args[:oidc_token] if args.key?(:oidc_token) @pubsub_wrapper = args[:pubsub_wrapper] if args.key?(:pubsub_wrapper) @push_endpoint = args[:push_endpoint] if args.key?(:push_endpoint) end |