Class: Google::Apis::AnalyticshubV1::QueryTemplate
- Inherits:
-
Object
- Object
- Google::Apis::AnalyticshubV1::QueryTemplate
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/analyticshub_v1/classes.rb,
lib/google/apis/analyticshub_v1/representations.rb,
lib/google/apis/analyticshub_v1/representations.rb
Overview
A query template is a container for sharing table-valued functions defined by contributors in a data clean room.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Required.
-
#documentation ⇒ String
Optional.
-
#name ⇒ String
Output only.
-
#primary_contact ⇒ String
Optional.
-
#proposer ⇒ String
Optional.
-
#routine ⇒ Google::Apis::AnalyticshubV1::Routine
Represents a bigquery routine.
-
#state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ QueryTemplate
constructor
A new instance of QueryTemplate.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ QueryTemplate
Returns a new instance of QueryTemplate.
2169 2170 2171 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2169 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when the QueryTemplate was created.
Corresponds to the JSON property createTime
2113 2114 2115 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2113 def create_time @create_time end |
#description ⇒ String
Optional. Short description of the QueryTemplate. The description must not
contain Unicode non-characters and C0 and C1 control codes except tabs (HT),
new lines (LF), carriage returns (CR), and page breaks (FF). Default value is
an empty string. Max length: 2000 bytes.
Corresponds to the JSON property description
2121 2122 2123 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2121 def description @description end |
#display_name ⇒ String
Required. Human-readable display name of the QueryTemplate. The display name
must contain only Unicode letters, numbers (0-9), underscores (_), dashes (-),
spaces ( ), ampersands (&) and can't start or end with spaces. Default value
is an empty string. Max length: 63 bytes.
Corresponds to the JSON property displayName
2129 2130 2131 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2129 def display_name @display_name end |
#documentation ⇒ String
Optional. Documentation describing the QueryTemplate.
Corresponds to the JSON property documentation
2134 2135 2136 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2134 def documentation @documentation end |
#name ⇒ String
Output only. The resource name of the QueryTemplate. e.g. projects/myproject/
locations/us/dataExchanges/123/queryTemplates/456
Corresponds to the JSON property name
2140 2141 2142 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2140 def name @name end |
#primary_contact ⇒ String
Optional. Email or URL of the primary point of contact of the QueryTemplate.
Max Length: 1000 bytes.
Corresponds to the JSON property primaryContact
2146 2147 2148 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2146 def primary_contact @primary_contact end |
#proposer ⇒ String
Optional. Will be deprecated. Email or URL of the primary point of contact of
the QueryTemplate. Max Length: 1000 bytes.
Corresponds to the JSON property proposer
2152 2153 2154 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2152 def proposer @proposer end |
#routine ⇒ Google::Apis::AnalyticshubV1::Routine
Represents a bigquery routine.
Corresponds to the JSON property routine
2157 2158 2159 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2157 def routine @routine end |
#state ⇒ String
Output only. The QueryTemplate lifecycle state.
Corresponds to the JSON property state
2162 2163 2164 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2162 def state @state end |
#update_time ⇒ String
Output only. Timestamp when the QueryTemplate was last modified.
Corresponds to the JSON property updateTime
2167 2168 2169 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2167 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2174 2175 2176 2177 2178 2179 2180 2181 2182 2183 2184 2185 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2174 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @documentation = args[:documentation] if args.key?(:documentation) @name = args[:name] if args.key?(:name) @primary_contact = args[:primary_contact] if args.key?(:primary_contact) @proposer = args[:proposer] if args.key?(:proposer) @routine = args[:routine] if args.key?(:routine) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |