Class: Google::Apis::AnalyticshubV1::Replica

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/analyticshub_v1/classes.rb,
lib/google/apis/analyticshub_v1/representations.rb,
lib/google/apis/analyticshub_v1/representations.rb

Overview

Represents the state of a replica of a shared dataset. It includes the geographic location of the replica and system-computed, output-only fields indicating its replication state and whether it is the primary replica.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Replica

Returns a new instance of Replica.



2246
2247
2248
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2246

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#locationString

Output only. The geographic location where the replica resides. See BigQuery locations for supported locations. Eg. "us-central1". Corresponds to the JSON property location

Returns:

  • (String)


2233
2234
2235
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2233

def location
  @location
end

#primary_stateString

Output only. Indicates that this replica is the primary replica. Corresponds to the JSON property primaryState

Returns:

  • (String)


2238
2239
2240
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2238

def primary_state
  @primary_state
end

#replica_stateString

Output only. Assigned by Analytics Hub based on real BigQuery replication state. Corresponds to the JSON property replicaState

Returns:

  • (String)


2244
2245
2246
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2244

def replica_state
  @replica_state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2251
2252
2253
2254
2255
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2251

def update!(**args)
  @location = args[:location] if args.key?(:location)
  @primary_state = args[:primary_state] if args.key?(:primary_state)
  @replica_state = args[:replica_state] if args.key?(:replica_state)
end