Class: Google::Apis::AnalyticshubV1::RestrictedExportPolicy
- Inherits:
-
Object
- Object
- Google::Apis::AnalyticshubV1::RestrictedExportPolicy
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/analyticshub_v1/classes.rb,
lib/google/apis/analyticshub_v1/representations.rb,
lib/google/apis/analyticshub_v1/representations.rb
Overview
Restricted export policy used to configure restricted export on linked dataset.
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean
(also: #enabled?)
Optional.
-
#restrict_direct_table_access ⇒ Boolean
(also: #restrict_direct_table_access?)
Optional.
-
#restrict_query_result ⇒ Boolean
(also: #restrict_query_result?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RestrictedExportPolicy
constructor
A new instance of RestrictedExportPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RestrictedExportPolicy
Returns a new instance of RestrictedExportPolicy.
2317 2318 2319 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2317 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enabled ⇒ Boolean Also known as: enabled?
Optional. If true, enable restricted export.
Corresponds to the JSON property enabled
2300 2301 2302 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2300 def enabled @enabled end |
#restrict_direct_table_access ⇒ Boolean Also known as: restrict_direct_table_access?
Optional. If true, restrict direct table access (read api/tabledata.list) on
linked table.
Corresponds to the JSON property restrictDirectTableAccess
2307 2308 2309 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2307 def restrict_direct_table_access @restrict_direct_table_access end |
#restrict_query_result ⇒ Boolean Also known as: restrict_query_result?
Optional. If true, restrict export of query result derived from restricted
linked dataset table.
Corresponds to the JSON property restrictQueryResult
2314 2315 2316 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2314 def restrict_query_result @restrict_query_result end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2322 2323 2324 2325 2326 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2322 def update!(**args) @enabled = args[:enabled] if args.key?(:enabled) @restrict_direct_table_access = args[:restrict_direct_table_access] if args.key?(:restrict_direct_table_access) @restrict_query_result = args[:restrict_query_result] if args.key?(:restrict_query_result) end |