Class: Google::Apis::AnalyticshubV1::RevokeSubscriptionRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/analyticshub_v1/classes.rb,
lib/google/apis/analyticshub_v1/representations.rb,
lib/google/apis/analyticshub_v1/representations.rb

Overview

Message for revoking a subscription.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RevokeSubscriptionRequest

Returns a new instance of RevokeSubscriptionRequest.



2374
2375
2376
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2374

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#revoke_commercialBoolean Also known as: revoke_commercial?

Optional. If the subscription is commercial then this field must be set to true, otherwise a failure is thrown. This acts as a safety guard to avoid revoking commercial subscriptions accidentally. Corresponds to the JSON property revokeCommercial

Returns:

  • (Boolean)


2371
2372
2373
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2371

def revoke_commercial
  @revoke_commercial
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2379
2380
2381
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2379

def update!(**args)
  @revoke_commercial = args[:revoke_commercial] if args.key?(:revoke_commercial)
end