Class: Google::Apis::AnalyticshubV1::SubscribeListingResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/analyticshub_v1/classes.rb,
lib/google/apis/analyticshub_v1/representations.rb,
lib/google/apis/analyticshub_v1/representations.rb

Overview

Message for response when you subscribe to a listing.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SubscribeListingResponse

Returns a new instance of SubscribeListingResponse.



2706
2707
2708
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2706

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#subscriptionGoogle::Apis::AnalyticshubV1::Subscription

A subscription represents a subscribers' access to a particular set of published data. It contains references to associated listings, data exchanges, and linked datasets. Corresponds to the JSON property subscription



2704
2705
2706
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2704

def subscription
  @subscription
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2711
2712
2713
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2711

def update!(**args)
  @subscription = args[:subscription] if args.key?(:subscription)
end