Class: Google::Apis::AnalyticshubV1::Subscription
- Inherits:
-
Object
- Object
- Google::Apis::AnalyticshubV1::Subscription
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/analyticshub_v1/classes.rb,
lib/google/apis/analyticshub_v1/representations.rb,
lib/google/apis/analyticshub_v1/representations.rb
Overview
A subscription represents a subscribers' access to a particular set of published data. It contains references to associated listings, data exchanges, and linked datasets.
Instance Attribute Summary collapse
-
#commercial_info ⇒ Google::Apis::AnalyticshubV1::GoogleCloudBigqueryAnalyticshubV1SubscriptionCommercialInfo
Commercial info metadata for this subscription.
-
#creation_time ⇒ String
Output only.
-
#data_exchange ⇒ String
Output only.
-
#destination_dataset ⇒ Google::Apis::AnalyticshubV1::DestinationDataset
Defines the destination bigquery dataset.
-
#last_modify_time ⇒ String
Output only.
-
#linked_dataset_map ⇒ Hash<String,Google::Apis::AnalyticshubV1::LinkedResource>
Output only.
-
#linked_resources ⇒ Array<Google::Apis::AnalyticshubV1::LinkedResource>
Output only.
-
#listing ⇒ String
Output only.
-
#log_linked_dataset_query_user_email ⇒ Boolean
(also: #log_linked_dataset_query_user_email?)
Output only.
-
#name ⇒ String
Output only.
-
#organization_display_name ⇒ String
Output only.
-
#organization_id ⇒ String
Output only.
-
#resource_type ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#subscriber_contact ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Subscription
constructor
A new instance of Subscription.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Subscription
Returns a new instance of Subscription.
2804 2805 2806 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2804 def initialize(**args) update!(**args) end |
Instance Attribute Details
#commercial_info ⇒ Google::Apis::AnalyticshubV1::GoogleCloudBigqueryAnalyticshubV1SubscriptionCommercialInfo
Commercial info metadata for this subscription.
Corresponds to the JSON property commercialInfo
2723 2724 2725 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2723 def commercial_info @commercial_info end |
#creation_time ⇒ String
Output only. Timestamp when the subscription was created.
Corresponds to the JSON property creationTime
2728 2729 2730 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2728 def creation_time @creation_time end |
#data_exchange ⇒ String
Output only. Resource name of the source Data Exchange. e.g. projects/123/
locations/us/dataExchanges/456
Corresponds to the JSON property dataExchange
2734 2735 2736 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2734 def data_exchange @data_exchange end |
#destination_dataset ⇒ Google::Apis::AnalyticshubV1::DestinationDataset
Defines the destination bigquery dataset.
Corresponds to the JSON property destinationDataset
2739 2740 2741 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2739 def destination_dataset @destination_dataset end |
#last_modify_time ⇒ String
Output only. Timestamp when the subscription was last modified.
Corresponds to the JSON property lastModifyTime
2744 2745 2746 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2744 def last_modify_time @last_modify_time end |
#linked_dataset_map ⇒ Hash<String,Google::Apis::AnalyticshubV1::LinkedResource>
Output only. Map of listing resource names to associated linked resource, e.g.
projects/123/locations/us/dataExchanges/456/listings/789 -> projects/123/
datasets/my_dataset For listing-level subscriptions, this is a map of size 1.
Only contains values if state == STATE_ACTIVE.
Corresponds to the JSON property linkedDatasetMap
2752 2753 2754 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2752 def linked_dataset_map @linked_dataset_map end |
#linked_resources ⇒ Array<Google::Apis::AnalyticshubV1::LinkedResource>
Output only. Linked resources created in the subscription. Only contains
values if state = STATE_ACTIVE.
Corresponds to the JSON property linkedResources
2758 2759 2760 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2758 def linked_resources @linked_resources end |
#listing ⇒ String
Output only. Resource name of the source Listing. e.g. projects/123/locations/
us/dataExchanges/456/listings/789
Corresponds to the JSON property listing
2764 2765 2766 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2764 def listing @listing end |
#log_linked_dataset_query_user_email ⇒ Boolean Also known as: log_linked_dataset_query_user_email?
Output only. By default, false. If true, the Subscriber agreed to the email
sharing mandate that is enabled for DataExchange/Listing.
Corresponds to the JSON property logLinkedDatasetQueryUserEmail
2770 2771 2772 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2770 def log_linked_dataset_query_user_email @log_linked_dataset_query_user_email end |
#name ⇒ String
Output only. The resource name of the subscription. e.g. projects/myproject/
locations/us/subscriptions/123.
Corresponds to the JSON property name
2777 2778 2779 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2777 def name @name end |
#organization_display_name ⇒ String
Output only. Display name of the project of this subscription.
Corresponds to the JSON property organizationDisplayName
2782 2783 2784 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2782 def organization_display_name @organization_display_name end |
#organization_id ⇒ String
Output only. Organization of the project this subscription belongs to.
Corresponds to the JSON property organizationId
2787 2788 2789 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2787 def organization_id @organization_id end |
#resource_type ⇒ String
Output only. Listing shared asset type.
Corresponds to the JSON property resourceType
2792 2793 2794 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2792 def resource_type @resource_type end |
#state ⇒ String
Output only. Current state of the subscription.
Corresponds to the JSON property state
2797 2798 2799 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2797 def state @state end |
#subscriber_contact ⇒ String
Output only. Email of the subscriber.
Corresponds to the JSON property subscriberContact
2802 2803 2804 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2802 def subscriber_contact @subscriber_contact end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2809 2810 2811 2812 2813 2814 2815 2816 2817 2818 2819 2820 2821 2822 2823 2824 2825 |
# File 'lib/google/apis/analyticshub_v1/classes.rb', line 2809 def update!(**args) @commercial_info = args[:commercial_info] if args.key?(:commercial_info) @creation_time = args[:creation_time] if args.key?(:creation_time) @data_exchange = args[:data_exchange] if args.key?(:data_exchange) @destination_dataset = args[:destination_dataset] if args.key?(:destination_dataset) @last_modify_time = args[:last_modify_time] if args.key?(:last_modify_time) @linked_dataset_map = args[:linked_dataset_map] if args.key?(:linked_dataset_map) @linked_resources = args[:linked_resources] if args.key?(:linked_resources) @listing = args[:listing] if args.key?(:listing) @log_linked_dataset_query_user_email = args[:log_linked_dataset_query_user_email] if args.key?(:log_linked_dataset_query_user_email) @name = args[:name] if args.key?(:name) @organization_display_name = args[:organization_display_name] if args.key?(:organization_display_name) @organization_id = args[:organization_id] if args.key?(:organization_id) @resource_type = args[:resource_type] if args.key?(:resource_type) @state = args[:state] if args.key?(:state) @subscriber_contact = args[:subscriber_contact] if args.key?(:subscriber_contact) end |